.. sphinx-autodoc-toolbox documentation master file, created by
   sphinx-quickstart on Sat Oct 29 22:59:28 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

sphinx-autodoc-toolbox
=============================

- GitHub: https://github.com/haiiliin/sphinx-autodoc-toolbox/
- Documentation: https://sphinx-autodoc-toolbox.readthedocs.io/en/latest/
- PyPI: https://pypi.org/project/sphinx-autodoc-toolbox/
- Read the Docs: https://readthedocs.org/projects/sphinx-autodoc-toolbox/

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   basic_usage

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
